==> order-center-domain-3.2.2-CLOUD-DEV-20240517.090613-17-sources.jar: com/tydic/dyc/oc/service/cmporder/UocQryCmpOrderDetailServiceImpl.java <==
package com.tydic.dyc.oc.service.cmporder;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.cmporder.IUocCmpOrderModel;
import com.tydic.dyc.oc.model.cmporder.qrybo.UocCmpOrderItemQryBo;
import com.tydic.dyc.oc.model.cmporder.qrybo.UocCmpOrderQryBo;
import com.tydic.dyc.oc.service.cmporder.bo.*;
import com.tydic.dyc.oc.utils.UocRu;
import lombok.extern.ohaotian.HTServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.ConcurrentMap;
import java.util.stream.Collectors;

/**
 * 描述: 〈领域服务-查询比价信息 实现〉
 * @author : yuhao
 * @date : 2022/8/1 11:05
 */
@HTServiceImpl
public class UocQryCmpOrderDetailServiceImpl implements UocGetCmpOrderDetailService {

    @Autowired
    private IUocCmpOrderModel uocCmpOrderModel;

    @Override
    public UocGetCmpOrderDetailServiceRspBo qryCmpOrderDetail(UocGetCmpOrderDetailServiceReqBo reqBo) {
        validateArg(reqBo);
        UocGetCmpOrderDetailServiceRspBo rspBo = UocRu.success(UocGetCmpOrderDetailServiceRspBo.class);
        UocCmpOrderQryBo uocCmpOrderQryBo = new UocCmpOrderQryBo();
        uocCmpOrderQryBo.setCmpOrderNo(reqBo.getCmpOrderNo());
        uocCmpOrderQryBo.setCmpOrderId(reqBo.getCmpOrderId());
        UocCmpOrderQryBo cmpOrderDetail = uocCmpOrderModel.qryCmpOrder(uocCmpOrderQryBo);
        if (ObjectUtil.isNotEmpty(cmpOrderDetail)) {
            UocGetCmpOrderDetailServiceRspDetailBo cmpOrderBo = UocRu.js(cmpOrderDetail, UocGetCmpOrderDetailServiceRspDetailBo.class);
            List<UocCmpOrderItemQryBo> uocCmpOrderItemList = cmpOrderDetail.getUocCmpOrderItemList();

            if (CollectionUtil.isNotEmpty(uocCmpOrderItemList)) {
                for(UocCmpOrderItemQryBo each: uocCmpOrderItemList){
                    each.setVendorId(each.getGoodsSupplierId());
                }
                cmpOrderBo.setUocCmpOrderItemList(UocRu.jsl(uocCmpOrderItemList, UocGetCmpOrderDetailServiceRspItemBo.class));
                //商品主图
                cmpOrderBo.setSkuMainPicUrl(uocCmpOrderItemList.get(0).getImgUrl());
                //前端格式商品明细
                cmpOrderBo.setUocCmpOrderItemFormatList(new ArrayList<>());
                ConcurrentMap<String, List<UocCmpOrderItemQryBo>> cmpOrderItemsMap = uocCmpOrderItemList.stream().collect(Collectors.groupingByConcurrent(UocCmpOrderItemQryBo::getSpuId));
                Iterator<String> iterator = cmpOrderItemsMap.keySet().iterator();
                while (iterator.hasNext()) {
                    String key = iterator.next();
                    UocGetCmpOrderDetailServiceRspItemFormatBo formatBo = new UocGetCmpOrderDetailServiceRspItemFormatBo();
                    formatBo.setCmpOrderNo(cmpOrderBo.getCmpOrderNo());
                    formatBo.setImgUrl(cmpOrderItemsMap.get(key).get(0).getImgUrl());
                    formatBo.setRemark(cmpOrderItemsMap.get(key).get(0).getRemark());
                    formatBo.setUocCmpItemFormatChildList(UocRu.jsl(cmpOrderItemsMap.get(key), UocGetCmpOrderDetailServiceRspItemFormatChildBo.class));
                    cmpOrderBo.getUocCmpOrderItemFormatList().add(formatBo);
                }
            }
            rspBo.setCmpOrderDetailinfo(cmpOrderBo);
        }
        return rspBo;
    }

    private void validateArg(UocGetCmpOrderDetailServiceReqBo reqBo) {
        if (reqBo == null) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参对象[UocGetCmpOrderDetailServiceReqBo]不能为空");
        }
        if (ObjectUtil.isEmpty(reqBo.getCmpOrderNo()) && ObjectUtil.isEmpty(reqBo.getCmpOrderId())) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参对象[比选单编号]和[比选单ID]不能同时为空");
        }
    }
}

==> order-center-domain-3.2.3-CLOUD-DEV-20241122.031858-21-sources.jar: com/tydic/dyc/oc/service/cmporder/UocQryCmpOrderDetailServiceImpl.java <==
package com.tydic.dyc.oc.service.cmporder;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.cmporder.IUocCmpOrderModel;
import com.tydic.dyc.oc.model.cmporder.qrybo.UocCmpOrderItemQryBo;
import com.tydic.dyc.oc.model.cmporder.qrybo.UocCmpOrderQryBo;
import com.tydic.dyc.oc.service.cmporder.bo.*;
import com.tydic.dyc.oc.utils.UocRu;
import lombok.extern.ohaotian.HTServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.ConcurrentMap;
import java.util.stream.Collectors;

/**
 * 描述: 〈领域服务-查询比价信息 实现〉
 * @author : yuhao
 * @date : 2022/8/1 11:05
 */
@HTServiceImpl
public class UocQryCmpOrderDetailServiceImpl implements UocGetCmpOrderDetailService {

    @Autowired
    private IUocCmpOrderModel uocCmpOrderModel;

    @Override
    public UocGetCmpOrderDetailServiceRspBo qryCmpOrderDetail(UocGetCmpOrderDetailServiceReqBo reqBo) {
        validateArg(reqBo);
        UocGetCmpOrderDetailServiceRspBo rspBo = UocRu.success(UocGetCmpOrderDetailServiceRspBo.class);
        UocCmpOrderQryBo uocCmpOrderQryBo = new UocCmpOrderQryBo();
        uocCmpOrderQryBo.setCmpOrderNo(reqBo.getCmpOrderNo());
        UocCmpOrderQryBo cmpOrderDetail = uocCmpOrderModel.qryCmpOrder(uocCmpOrderQryBo);
        if (ObjectUtil.isNotEmpty(cmpOrderDetail)) {
            UocGetCmpOrderDetailServiceRspDetailBo cmpOrderBo = UocRu.js(cmpOrderDetail, UocGetCmpOrderDetailServiceRspDetailBo.class);
            List<UocCmpOrderItemQryBo> uocCmpOrderItemList = cmpOrderDetail.getUocCmpOrderItemList();

            if (CollectionUtil.isNotEmpty(uocCmpOrderItemList)) {
                for(UocCmpOrderItemQryBo each: uocCmpOrderItemList){
                    each.setVendorId(each.getGoodsSupplierId());
                }
                cmpOrderBo.setUocCmpOrderItemList(UocRu.jsl(uocCmpOrderItemList, UocGetCmpOrderDetailServiceRspItemBo.class));
                //商品主图
                cmpOrderBo.setSkuMainPicUrl(uocCmpOrderItemList.get(0).getImgUrl());
                //前端格式商品明细
                cmpOrderBo.setUocCmpOrderItemFormatList(new ArrayList<>());
                ConcurrentMap<String, List<UocCmpOrderItemQryBo>> cmpOrderItemsMap = uocCmpOrderItemList.stream().collect(Collectors.groupingByConcurrent(UocCmpOrderItemQryBo::getSpuId));
                Iterator<String> iterator = cmpOrderItemsMap.keySet().iterator();
                while (iterator.hasNext()) {
                    String key = iterator.next();
                    UocGetCmpOrderDetailServiceRspItemFormatBo formatBo = new UocGetCmpOrderDetailServiceRspItemFormatBo();
                    formatBo.setCmpOrderNo(cmpOrderBo.getCmpOrderNo());
                    formatBo.setImgUrl(cmpOrderItemsMap.get(key).get(0).getImgUrl());
                    formatBo.setRemark(cmpOrderItemsMap.get(key).get(0).getRemark());
                    formatBo.setUocCmpItemFormatChildList(UocRu.jsl(cmpOrderItemsMap.get(key), UocGetCmpOrderDetailServiceRspItemFormatChildBo.class));
                    cmpOrderBo.getUocCmpOrderItemFormatList().add(formatBo);
                }
            }
            rspBo.setCmpOrderDetailinfo(cmpOrderBo);
        }
        return rspBo;
    }

    private void validateArg(UocGetCmpOrderDetailServiceReqBo reqBo) {
        if (reqBo == null) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参对象[UocGetCmpOrderDetailServiceReqBo]不能为空");
        }
        if (ObjectUtil.isEmpty(reqBo.getCmpOrderNo())) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参对象[比价单编号]不能为空");
        }
    }
}
